@@ -11,8 +11,9 @@
 #include "collectionattributespage.h"
 #include "collectioninternalspage.h"
 #include "config-akonadiconsole.h"
-#include "dbaccess.h"
 #include "tagpropertiesdialog.h"
+#include <Akonadi/ClearCacheJob>
+#include <Akonadi/DbAccess>
 
 #include <Akonadi/AttributeFactory>
 #include <Akonadi/ChangeRecorder>
@@ -64,9 +65,9 @@
 #include <QTimer>
 #include <QVBoxLayout>
 
-#ifdef ENABLE_CONTENTVIEWS
-#include <Akonadi/Contact/ContactGroupViewer>
-#include <Akonadi/Contact/ContactViewer>
+#if ENABLE_CONTENTVIEWS
+#include <Akonadi/ContactGroupViewer>
+#include <Akonadi/ContactViewer>
 #include <CalendarSupport/IncidenceViewer>
 #include <MessageViewer/Viewer>
 #endif
@@ -195,7 +196,7 @@ BrowserWidget::BrowserWidget(KXmlGuiWindow *xmlGuiWindow, QWidget *parent)
     connect(contentUi.saveButton, &QPushButton::clicked, this, &BrowserWidget::save);
     splitter3->addWidget(contentViewParent);
 
-#ifdef ENABLE_CONTENTVIEWS
+#if ENABLE_CONTENTVIEWS
     auto w = new QWidget;
     w->setLayout(new QVBoxLayout);
     w->layout()->addWidget(mContactView = new Akonadi::ContactViewer);
@@ -308,7 +309,7 @@ void BrowserWidget::contentViewChanged()
 void BrowserWidget::setItem(const Akonadi::Item &item)
 {
     mCurrentItem = item;
-#ifdef ENABLE_CONTENTVIEWS
+#if ENABLE_CONTENTVIEWS
     if (item.hasPayload<KContacts::Addressee>()) {
         mContactView->setItem(item);
         contentUi.stack->setCurrentWidget(mContactView->parentWidget());
@@ -526,52 +527,10 @@ void BrowserWidget::dumpToXmlResult(KJob *job)
 
 void BrowserWidget::clearCache()
 {
-    const Collection coll = currentCollection();
-    if (!coll.isValid()) {
-        return;
-    }
-
-    const auto ridCount = QStringLiteral("SELECT COUNT(*) FROM PimItemTable WHERE collectionId=%1 AND remoteId=''").arg(coll.id());
-    QSqlQuery query(DbAccess::database());
-    if (!query.exec(ridCount)) {
-        qCWarning(AKONADICONSOLE_LOG) << "Failed to execute query" << ridCount << ":" << query.lastError().text();
-        KMessageBox::error(this, query.lastError().text());
-        return;
-    }
-
-    query.next();
-    const int emptyRidCount = query.value(0).toInt();
-    if (emptyRidCount > 0) {
-        if (KMessageBox::warningContinueCancel(this,
-                                               QStringLiteral("The collection '%1' contains %2 items without Remote ID. "
-                                                              "Those items were likely never uploaded to the destination server, "
-                                                              "so clearing this collection means that those <b>data will be lost</b>. "
-                                                              "Are you sure you want to proceed?")
-                                                   .arg(coll.id())
-                                                   .arg(emptyRidCount),
-                                               QStringLiteral("POSSIBLE DATA LOSS!"))
-            == KMessageBox::Cancel) {
-            return;
-        }
-    }
-
-    QString str = QStringLiteral("DELETE FROM PimItemTable WHERE collectionId=%1").arg(coll.id());
-    qCDebug(AKONADICONSOLE_LOG) << str;
-    query = QSqlQuery(str, DbAccess::database());
-    if (query.exec()) {
-        if (query.lastError().isValid()) {
-            qCDebug(AKONADICONSOLE_LOG) << query.lastError();
-            KMessageBox::error(this, query.lastError().text());
-        }
-    }
-
-    // TODO: Clear external parts
-    // TODO: Reset Akonadi's internal collection statistics cache
-    // TODO: Notify all clients EXCEPT FOR THE RESOURCE about the deletion?
-    // TODO: Clear search index
-    // TODO: ???
-
-    KMessageBox::information(this, QStringLiteral("Collection cache cleared. You should restart Akonadi now."));
+    Akonadi::ClearCacheJob *job = new Akonadi::ClearCacheJob(this);
+    job->setCollection(currentCollection());
+    job->setParentWidget(this);
+    job->start();
 }
 
 Akonadi::Collection BrowserWidget::currentCollection() const
